/*-
 ***********************************************************************
 *
 * $Id: all-includes.h,v 1.15 2012/01/07 07:56:14 mavrik Exp $
 *
 ***********************************************************************
 *
 * Copyright 2001-2012 The WebJob Project, All Rights Reserved.
 *
 ***********************************************************************
 */
#ifndef _ALL_INCLUDES_H_INCLUDED
#define _ALL_INCLUDES_H_INCLUDED

#if defined(UNIX) || defined(MINGW32)
#include "config.h"
#endif

#include "sys-includes.h"
#include "app-includes.h"

#endif /* !_ALL_INCLUDES_H_INCLUDED */
